@@ -22,6 +22,9 @@ from .download import download
 from .anime_info import AnimeInfo
 from .config import config
 
+# Make colors work in windows CMD 
+os.system("")
+
 rpc_client = None
 if config.dc_presence:
     rpc_client = dc_presence_connect()
